thorn.funtests.tasks — Thorn 1.3.0 documentation

# thorn.funtests.tasks

- thorn.funtests.tasks

## thorn.funtests.tasks

Custom Celery worker remote control commands used in the Thorn functional test suite.

`thorn.funtests.tasks.` `find_subscriber`(self, subs, url)

`thorn.funtests.tasks.` `hook_clear`(state, event)

`thorn.funtests.tasks.` `hook_subscribe`(state, event, url=None, callback=None)

`thorn.funtests.tasks.` `hook_unsubscribe`(state, event, url)

`thorn.funtests.tasks.` `setenv`(state, setting_name, new_value)

`thorn.funtests.tasks.` `subscribers_for_event`(event)